@@ -13,6 +13,7 @@ use 5.010;
 use strict;
 use warnings;
 
+use Games::Risk::GUI::Constants;
 use List::Util qw{ max };
 use POE;
 use Tk;
@@ -20,24 +21,6 @@ use Tk::Font;
 
 use aliased 'POE::Kernel' => 'K';
 
-my @TOP     = ( -side => 'top'    );
-my @BOTTOM  = ( -side => 'bottom' );
-my @LEFT    = ( -side => 'left'   );
-my @RIGHT   = ( -side => 'right'  );
-
-my @FILLX   = ( -fill => 'x'    );
-my @FILL2   = ( -fill => 'both' );
-my @XFILLX  = ( -expand => 1, -fill => 'x'    );
-my @XFILL2  = ( -expand => 1, -fill => 'both' );
-
-my @PAD1    = ( -padx => 1, -pady => 1);
-my @PAD20   = ( -padx => 20, -pady => 20);
-
-my @ENON    = ( -state => 'normal' );
-my @ENOFF   = ( -state => 'disabled' );
-
-
-
 
 #--
 # Constructor
